hugh: Seal "hugh" dive data.
Description
A sample of recorded field data from a seal. The seal makes 6 dives with 5 surface intervals. Data have been pre-filtered but are in somewhat of an intermediate form for the purposes of examples within the animalTrack package.
Format
A data frame with 13,953 observations on the following 21 variables.
Year- year
Month- month
Day- day
Hour- hour
Minute- minute
Second- second
MX- a numeric vector of magnetometer X-axis values (in bits)
MY- a numeric vector of magnetometer Y-axis values (in bits)
MZ- a numeric vector of magnetometer Z-axis values (in bits)
depth.cal- depth (meters)
MX2- a numeric vector of temperature calibrated magnetometer x-axis values (in bits)
MY2- a numeric vector of temperature calibrated magnetometer Y-axis values (in bits)
MZ2- a numeric vector of temperature calibrated magnetometer Z-axis values (in bits)
MXone- a numeric vector of temperature calibrated magnetometer X-axis values scaled from -1 to +1
MYone- a numeric vector of temperature calibrated magnetometer Y-axis values scaled from -1 to +1
MZone- a numeric vector of temperature calibrated magnetometer Z-axis values scaled from -1 to +1
speed.cal- calibrated speed (meters per second)
Ax.dec- a numeric vector of calibrated accelerometer x-axis values scaled from -1 to +1g. A low-pass filter was applied in
order to obtain "static" acceleration.
Ay.dec- a numeric vector of calibrated accelerometer Y-axis values scaled from -1 to +1g. A low-pass filter was applied in
order to obtain "static" acceleration.
Az.dec- a numeric vector of calibrated accelerometer Z-axis values scaled from -1 to +1g. A low-pass filter was applied in
order to obtain "static" acceleration.
diven- dive number
Data were collected under NSF Grant #0739390 and NOAA Marine Mammal Permit #984-1814.